Changelog
=========

0.1.2 (2018-12-14)
------------------
* Added support for nested unions and intersections

0.1.1 (2018-07-16)
------------------

* Cached the queryset generated after applying the delayed operation.

0.1.0 (2018-03-14)
------------------

* First release on PyPI.
